@@ -1,6 +1,7 @@
 /*
  * NamedMashEditor.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,22 +18,23 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _NAMEDMASHEDITOR_H
-#define   _NAMEDMASHEDITOR_H
+#ifndef NAMEDMASHEDITOR_H
+#define NAMEDMASHEDITOR_H
 
 class NamedMashEditor;
 
 #include <QDialog>
 #include <QMetaProperty>
+#include <QString>
 #include <QVariant>
+#include <QWidget>
 
 #include "ui_namedMashEditor.h"
-#include "MashStepTableModel.h"
 #include "MashListModel.h"
 #include "MashStepEditor.h"
 #include "EquipmentListModel.h"
-#include "BeerXMLSortProxyModel.h"
+#include "NamedEntitySortProxyModel.h"
+#include "tableModels/MashStepTableModel.h"
 
 
 // Forward declarations.
@@ -42,12 +44,12 @@ class Equipment;
 
 /*!
  * \class NamedMashEditor
- * \author Philip G. Lee
  *
  * \brief View/controller dialog for editing a mash.
+ *
+ *        See also \c MashEditor
  */
-class NamedMashEditor : public QDialog, public Ui::namedMashEditor
-{
+class NamedMashEditor : public QDialog, public Ui::namedMashEditor {
    Q_OBJECT
 public:
    NamedMashEditor( QWidget *parent = 0, MashStepEditor* editor =0, bool singleMashEditor = false );
@@ -61,7 +63,7 @@ public slots:
    void saveAndClose();
    //! Set the mash we wish to view/edit.
    void setMash(Mash* mash);
-  
+
    //! add a mash step to the mash
    void addMashStep();
    //! remove a mash step to the mash
@@ -101,5 +103,4 @@ private:
 
 };
 
-#endif   /* _NAMEDMASHEDITOR_H */
-
+#endif
